@@ -1,10 +1,10 @@
-import aiofiles
-import distro
 import logging
 import os
 import re
 from typing import Tuple
 
+import aiofiles
+import distro
 
 log = logging.getLogger(__name__)
 
@@ -75,14 +75,6 @@ _OS_FAMILY_MAP = {
     "openSUSE Leap": "Suse",
     "openSUSE Tumbleweed": "Suse",
     "SLES_SAP": "Suse",
-    "Solaris": "Solaris",
-    "SmartOS": "Solaris",
-    "OmniOS": "Solaris",
-    "OpenIndiana Development": "Solaris",
-    "OpenIndiana": "Solaris",
-    "OpenSolaris Development": "Solaris",
-    "OpenSolaris": "Solaris",
-    "Oracle Solaris": "Solaris",
     "Arch ARM": "Arch",
     "Manjaro": "Arch",
     "Antergos": "Arch",
@@ -106,7 +98,6 @@ _OS_FAMILY_MAP = {
     "Void": "Void",
     "IDMS": "Debian",
     "Funtoo": "Gentoo",
-    "AIX": "AIX",
     "TurnKey": "Debian",
 }
 
@@ -134,10 +125,6 @@ async def _get_synology_osrelease(osrelease: str) -> str:
                 return f'{synoinfo["majorversion"]}.{synoinfo["minorversion"]}-{synoinfo["buildnumber"]}'
 
 
-async def _get_osrelease_info(osrelease: str) -> Tuple:
-    return tuple(int(x) if x.isdigit() else x for x in osrelease.split("."))
-
-
 async def _get_os(osfullname: str) -> str:
     distroname = _REPLACE_LINUX_RE.sub("", osfullname).strip()
 
@@ -152,10 +139,14 @@ async def _get_os(osfullname: str) -> str:
 async def load_manufacturer(hub):
     # TODO There has got to be a way to programmatically determine this
     # For example, ubuntu is manufactuerd by Canonical, etc...
-    hub.corn.CORN.osmanufactuer = "unknown"
+    hub.corn.CORN.osmanufacturer = "unknown"
 
 
 async def load_linux_distribution(hub):
+    release_info = lambda osrelease: tuple(
+        int(x) if x.strip().isdigit() else x for x in osrelease.split(".")
+    )
+
     info = distro.LinuxDistribution()
     hub.corn.CORN.osbuild = info.build_number()
     hub.corn.CORN.oscodename = info.codename().strip("\"'")
@@ -178,7 +169,7 @@ async def load_linux_distribution(hub):
         # This will likely have been defined elsewhere, dereference and redefine
         del hub.corn.CORN.ps
         hub.corn.CORN.ps = "ps -o user,pid,ppid,tty,time,comm"
-    hub.corn.CORN.osrelease_info = await _get_osrelease_info(hub.corn.CORN.osrelease)
+    hub.corn.CORN.osrelease_info = release_info(hub.corn.CORN.osrelease)
 
     major_version = info.major_version().strip("\"'")
     hub.corn.CORN.osmajorrelease = (
@@ -195,4 +186,4 @@ async def load_linux_distribution(hub):
         else hub.corn.CORN.osrelease_info[0]
     )
     if os_name and finger:
-        hub.corn.CORN.osfinger = f"{os_name}-{finger}"
+        hub.corn.CORN.osfinger = f"{os_name.split()[-1]}-{finger}"
